#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec
version:              2.11.7
visibility:           public
id:                   hspec-2.11.7-3Kp3PTiLFy0JhU2sO60TrZ
key:                  hspec-2.11.7-3Kp3PTiLFy0JhU2sO60TrZ
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    Hspec is a testing framework for Haskell.  Some of Hspec'\''s distinctive
    features are:

    * a friendly DSL for defining tests

    * integration with QuickCheck, SmallCheck, and HUnit

    * parallel test execution

    * automatic discovery of test files

    The Hspec Manual is at <https://hspec.github.io/>.

category:             Testing
abi:                  813ef90ac6c325e5b81adc52d4d3d4be
exposed:              True
exposed-modules:
    Test.Hspec Test.Hspec.Discover Test.Hspec.Formatters
    Test.Hspec.QuickCheck Test.Hspec.Runner

hidden-modules:       Paths_hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-2.11.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-2.11.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-2.11.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec
hs-libraries:         HShspec-2.11.7-3Kp3PTiLFy0JhU2sO60TrZ
depends:
    QuickCheck-2.15.0.1-K0JFHgomBHu3hU8T85EWwT base-4.18.2.1
    hspec-core-2.11.7-7fX3F8gLgA3T5SWesER1k
    hspec-discover-2.11.7-CyhF7PHm7BkFVcJGhl1vui
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa

haddock-interfaces:   /usr/share/doc/haskell-hspec/html/hspec.haddock
haddock-html:         /usr/share/doc/haskell-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

